use domain::dto::social_wx::{WxLoginInfo, WxMinAppLogin};
use library::{
    context::Context,
    extractor::body_extractor::JsonBody,
    model::response::ResResult,
    social::wechat::{MiniAppLoginResult, WeChatAccessToken},
};
use macros::{get, post};

use crate::service::social_wx_service;

/// 获取微信access_token
#[get("/wechat/access_token")]
pub async fn get_wechat_access_token(context: Context) -> ResResult<WeChatAccessToken> {
    social_wx_service::get_wechat_access_token(context).await
}

/// 微信用户登录，code通过wx.login获取
///
/// TODO 登录成功后，判断用户是否存在，不存在，则注册用户，存在，则更新用户信息
#[post("/wechat/code_2_session")]
pub async fn code_2_session(
    context: Context,
    JsonBody(mini_app_login): JsonBody<WxMinAppLogin>,
) -> ResResult<MiniAppLoginResult> {
    social_wx_service::code_2_session(context, mini_app_login.code.unwrap()).await
}

/// 微信用户登录校验
#[post("/wechat/check_session")]
pub async fn check_session(
    context: Context,
    JsonBody(wx_login_info): JsonBody<WxLoginInfo>,
) -> ResResult<()> {
    social_wx_service::check_session(context, wx_login_info).await
}
